@@ -11,8 +11,6 @@ namespace Zend\Authentication\Adapter\Exception;
 
 use Zend\Authentication\Exception;
 
-class InvalidArgumentException
-    extends Exception\InvalidArgumentException
-    implements ExceptionInterface
+class InvalidArgumentException extends Exception\InvalidArgumentException implements ExceptionInterface
 {
 }
