@@ -12,8 +12,6 @@ namespace Zend\Barcode\Exception;
 /**
  * Exception for Zend\Barcode component.
  */
-class RendererCreationException
-    extends \InvalidArgumentException
-    implements ExceptionInterface
+class RendererCreationException extends \InvalidArgumentException implements ExceptionInterface
 {
 }
