@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2013 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -194,7 +194,7 @@ abstract class AbstractAdapter implements StorageInterface, EventsCapableInterfa
     }
 
     /**
-     * Trigger an pre event and return the event response collection
+     * Trigger a pre event and return the event response collection
      *
      * @param  string $eventName
      * @param  ArrayObject $args
@@ -1537,7 +1537,7 @@ abstract class AbstractAdapter implements StorageInterface, EventsCapableInterfa
             );
         } elseif (($p = $this->getOptions()->getKeyPattern()) && !preg_match($p, $key)) {
             throw new Exception\InvalidArgumentException(
-                "The key '{$key}' doesn't match agains pattern '{$p}'"
+                "The key '{$key}' doesn't match against pattern '{$p}'"
             );
         }
     }
