@@ -832,7 +832,6 @@ class Getopt
         $this->_setSingleOptionValue($realFlag, $param);
     }
 
-
     /**
      * Set given value as value of numeric option
      *
@@ -924,14 +923,16 @@ class Getopt
                 if (preg_match('/\W/', $param)) {
                     throw new Exception\RuntimeException(
                         "Option \"$flag\" requires a single-word parameter, but was given \"$param\".",
-                        $this->getUsageMessage());
+                        $this->getUsageMessage()
+                    );
                 }
                 break;
             case 'integer':
                 if (preg_match('/\D/', $param)) {
                     throw new Exception\RuntimeException(
                         "Option \"$flag\" requires an integer parameter, but was given \"$param\".",
-                        $this->getUsageMessage());
+                        $this->getUsageMessage()
+                    );
                 }
                 break;
             case 'string':
@@ -1007,14 +1008,16 @@ class Getopt
                 if (strlen($flag) == 1) {
                     if (isset($this->ruleMap[$flag])) {
                         throw new Exception\InvalidArgumentException(
-                            "Option \"-$flag\" is being defined more than once.");
+                            "Option \"-$flag\" is being defined more than once."
+                        );
                     }
                     $this->ruleMap[$flag] = $mainFlag;
                     $rule['alias'][] = $flag;
                 } else {
                     if (isset($this->rules[$flag]) || isset($this->ruleMap[$flag])) {
                         throw new Exception\InvalidArgumentException(
-                            "Option \"--$flag\" is being defined more than once.");
+                            "Option \"--$flag\" is being defined more than once."
+                        );
                     }
                     $this->ruleMap[$flag] = $mainFlag;
                     $rule['alias'][] = $flag;
