@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2013 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -17,12 +17,10 @@ namespace Zend\Http\Header;
 class AcceptRanges implements HeaderInterface
 {
 
-    protected $rangeUnit = null;
+    protected $rangeUnit;
 
     public static function fromString($headerLine)
     {
-        $header = new static();
-
         list($name, $value) = GenericHeader::splitHeaderLine($headerLine);
 
         // check to ensure proper header type for this factory
@@ -30,11 +28,16 @@ class AcceptRanges implements HeaderInterface
             throw new Exception\InvalidArgumentException('Invalid header line for Accept-Ranges string');
         }
 
-        $header->rangeUnit = trim($value);
+        $header = new static($value);
 
         return $header;
     }
 
+    public function __construct($rangeUnit = null)
+    {
+        $this->rangeUnit = $rangeUnit;
+    }
+
     public function getFieldName()
     {
         return 'Accept-Ranges';
