@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2013 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -15,11 +15,11 @@ namespace Zend\Http\Header;
  */
 class IfMatch implements HeaderInterface
 {
+    /** @var string */
+    protected $value;
 
     public static function fromString($headerLine)
     {
-        $header = new static();
-
         list($name, $value) = GenericHeader::splitHeaderLine($headerLine);
 
         // check to ensure proper header type for this factory
@@ -28,11 +28,16 @@ class IfMatch implements HeaderInterface
         }
 
         // @todo implementation details
-        $header->value = $value;
+        $header = new static($value);
 
         return $header;
     }
 
+    public function __construct($value = null)
+    {
+        $this->value = $value;
+    }
+
     public function getFieldName()
     {
         return 'If-Match';
