@@ -193,11 +193,12 @@ abstract class AbstractContainer implements Countable, RecursiveIterator
     /**
      * Removes the given page from the container
      *
-     * @param  Page\AbstractPage|int $page page to remove, either a page
-     *                                     instance or a specific page order
+     * @param  Page\AbstractPage|int $page      page to remove, either a page
+     *                                          instance or a specific page order
+     * @param  bool                  $recursive [optional] whether to remove recursively
      * @return bool whether the removal was successful
      */
-    public function removePage($page)
+    public function removePage($page, $recursive = false)
     {
         if ($page instanceof Page\AbstractPage) {
             $hash = $page->hashCode();
@@ -217,6 +218,16 @@ abstract class AbstractContainer implements Countable, RecursiveIterator
             return true;
         }
 
+        if ($recursive) {
+            /** @var \Zend\Navigation\Page\AbstractPage $childPage */
+            foreach ($this->pages as $childPage) {
+                if ($childPage->hasPage($page, true)) {
+                    $childPage->removePage($page, true);
+                    return true;
+                }
+            }
+        }
+
         return false;
     }
 
