@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2013 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -59,14 +59,14 @@ class ServiceManager implements ServiceLocatorInterface
     protected $pendingAbstractFactoryRequests = array();
 
     /**
-     * @var string
+     * @var integer
      */
-    protected $lastAbstractFactoryUsed = null;
+    protected $nestedContextCounter = -1;
 
     /**
-     * @var string
+     * @var array
      */
-    protected $lastCanonicalNameUsed   = null;
+    protected $nestedContext = array();
 
     /**
      * @var array
@@ -494,6 +494,7 @@ class ServiceManager implements ServiceLocatorInterface
         }
 
         if (!$instance) {
+            $this->checkNestedContextStart($cName);
             if (
                 isset($this->invokableClasses[$cName])
                 || isset($this->factories[$cName])
@@ -501,13 +502,23 @@ class ServiceManager implements ServiceLocatorInterface
                 || $this->canCreateFromAbstractFactory($cName, $name)
             ) {
                 $instance = $this->create(array($cName, $name));
+            } elseif ($isAlias && $this->canCreateFromAbstractFactory($name, $cName)) {
+                /*
+                 * case of an alias leading to an abstract factory :
+                 * 'my-alias' => 'my-abstract-defined-service'
+                 *     $name = 'my-alias'
+                 *     $cName = 'my-abstract-defined-service'
+                 */
+                $instance = $this->create(array($name, $cName));
             } elseif ($usePeeringServiceManagers && !$this->retrieveFromPeeringManagerFirst) {
                 $instance = $this->retrieveFromPeeringManager($name);
             }
+            $this->checkNestedContextStop();
         }
 
         // Still no instance? raise an exception
         if ($instance === null) {
+            $this->checkNestedContextStop(true);
             if ($isAlias) {
                 throw new Exception\ServiceNotFoundException(sprintf(
                     'An alias "%s" was requested but no service could be found.',
@@ -604,12 +615,14 @@ class ServiceManager implements ServiceLocatorInterface
         if ($instance === null && isset($this->invokableClasses[$cName])) {
             $instance = $this->createFromInvokable($cName, $rName);
         }
-
+        $this->checkNestedContextStart($cName);
         if ($instance === null && $this->canCreateFromAbstractFactory($cName, $rName)) {
             $instance = $this->createFromAbstractFactory($cName, $rName);
         }
+        $this->checkNestedContextStop();
 
         if ($instance === null && $this->throwExceptionInCreate) {
+            $this->checkNestedContextStop(true);
             throw new Exception\ServiceNotFoundException(sprintf(
                 'No valid instance was found for %s%s',
                 $cName,
@@ -635,65 +648,57 @@ class ServiceManager implements ServiceLocatorInterface
 
     /**
      * Determine if we can create an instance.
+     * Proxies to has()
      *
      * @param  string|array $name
      * @param  bool         $checkAbstractFactories
      * @return bool
-     *
-     * @deprecated this method is being deprecated as of zendframework 2.2, and may be removed in future major versions
+     * @deprecated this method is being deprecated as of zendframework 2.3, and may be removed in future major versions
      */
     public function canCreate($name, $checkAbstractFactories = true)
     {
-        if (is_array($name)) {
-            list($cName, $rName) = $name;
-        } else {
-            $rName = $name;
-            $cName = $this->canonicalizeName($rName);
-        }
-
-        return (
-            isset($this->invokableClasses[$cName])
-            || isset($this->factories[$cName])
-            || isset($this->aliases[$cName])
-            || isset($this->instances[$cName])
-            || ($checkAbstractFactories && $this->canCreateFromAbstractFactory($cName, $rName))
-        );
+        trigger_error(sprintf('%s is deprecated; please use %s::has', __METHOD__, __CLASS__), E_USER_DEPRECATED);
+        return $this->has($name, $checkAbstractFactories, false);
     }
 
     /**
-     * @param  string|array  $name
+     * Determine if an instance exists.
+     *
+     * @param  string|array  $name  An array argument accepts exactly two values.
+     *                              Example: array('canonicalName', 'requestName')
      * @param  bool          $checkAbstractFactories
      * @param  bool          $usePeeringServiceManagers
      * @return bool
      */
     public function has($name, $checkAbstractFactories = true, $usePeeringServiceManagers = true)
     {
-        if (is_array($name)) {
-            list($cName, $rName) = $name;
-        } else {
+        if (is_string($name)) {
             $rName = $name;
 
             // inlined code from ServiceManager::canonicalizeName for performance
             if (isset($this->canonicalNames[$rName])) {
-                $cName = $this->canonicalNames[$name];
+                $cName = $this->canonicalNames[$rName];
             } else {
                 $cName = $this->canonicalizeName($name);
             }
+        } elseif (is_array($name) && count($name) >= 2) {
+            list($cName, $rName) = $name;
+        } else {
+            return false;
         }
 
-        if (
-            isset($this->invokableClasses[$cName])
+        if (isset($this->invokableClasses[$cName])
             || isset($this->factories[$cName])
             || isset($this->aliases[$cName])
             || isset($this->instances[$cName])
-            || ($checkAbstractFactories && $this->canCreateFromAbstractFactory($cName, $name))
+            || ($checkAbstractFactories && $this->canCreateFromAbstractFactory($cName, $rName))
         ) {
             return true;
         }
 
         if ($usePeeringServiceManagers) {
             foreach ($this->peeringServiceManagers as $peeringServiceManager) {
-                if ($peeringServiceManager->has($rName)) {
+                if ($peeringServiceManager->has($name)) {
                     return true;
                 }
             }
@@ -711,33 +716,33 @@ class ServiceManager implements ServiceLocatorInterface
      */
     public function canCreateFromAbstractFactory($cName, $rName)
     {
-        // check abstract factories
-        foreach ($this->abstractFactories as $abstractFactory) {
-            $factoryClass = get_class($abstractFactory);
-
-            if (
-                isset($this->pendingAbstractFactoryRequests[$factoryClass])
-                && $this->pendingAbstractFactoryRequests[$factoryClass] == $rName
-            ) {
+        if (array_key_exists($cName, $this->nestedContext)) {
+            $context = $this->nestedContext[$cName];
+            if ($context === false) {
                 return false;
-            }
-
-            $objectHash = spl_object_hash($abstractFactory);
-
-            if ($this->lastAbstractFactoryUsed === $objectHash && $this->lastCanonicalNameUsed === $cName) {
-                $this->lastAbstractFactoryUsed = $this->lastCanonicalNameUsed = null;
-                return false;
-            }
-
-            $this->lastAbstractFactoryUsed = $objectHash;
-            $this->lastCanonicalNameUsed   = $cName;
-
-            if ($abstractFactory->canCreateServiceWithName($this, $cName, $rName)) {
-                $this->lastAbstractFactoryUsed = $this->lastCanonicalNameUsed = null;
-                return true;
+            } elseif (is_object($context)) {
+                return !isset($this->pendingAbstractFactoryRequests[get_class($context).$cName]);
             }
         }
-        return false;
+        $this->checkNestedContextStart($cName);
+        // check abstract factories
+        $result = false;
+        $this->nestedContext[$cName] = false;
+        foreach ($this->abstractFactories as $abstractFactory) {
+            $pendingKey = get_class($abstractFactory).$cName;
+            if (isset($this->pendingAbstractFactoryRequests[$pendingKey])) {
+                $result = false;
+                break;
+            }
+
+            if ($abstractFactory->canCreateServiceWithName($this, $cName, $rName)) {
+                $this->nestedContext[$cName] = $abstractFactory;
+                $result = true;
+                break;
+            }
+        }
+        $this->checkNestedContextStop();
+        return $result;
     }
 
     /**
@@ -1047,31 +1052,21 @@ class ServiceManager implements ServiceLocatorInterface
      */
     protected function createFromAbstractFactory($canonicalName, $requestedName)
     {
-        foreach ($this->abstractFactories as $index => $abstractFactory) {
-            // support factories as strings
-            if (is_string($abstractFactory) && class_exists($abstractFactory, true)) {
-                $this->abstractFactories[$index] = $abstractFactory = new $abstractFactory;
-            } elseif (!$abstractFactory instanceof AbstractFactoryInterface) {
-                throw new Exception\ServiceNotCreatedException(sprintf(
-                    'While attempting to create %s%s an abstract factory could not produce a valid instance.',
-                    $canonicalName,
-                    ($requestedName ? '(alias: ' . $requestedName . ')' : '')
-                ));
-            }
+        if (isset($this->nestedContext[$canonicalName])) {
+            $abstractFactory = $this->nestedContext[$canonicalName];
+            $pendingKey = get_class($abstractFactory).$canonicalName;
             try {
-                if ($abstractFactory->canCreateServiceWithName($this, $canonicalName, $requestedName)) {
-                    $this->pendingAbstractFactoryRequests[get_class($abstractFactory)] = $requestedName;
-                    $instance = $this->createServiceViaCallback(
-                        array($abstractFactory, 'createServiceWithName'),
-                        $canonicalName,
-                        $requestedName
-                    );
-                    unset($this->pendingAbstractFactoryRequests[get_class($abstractFactory)]);
-                } else {
-                    $instance = null;
-                }
+                $this->pendingAbstractFactoryRequests[$pendingKey] = true;
+                $instance = $this->createServiceViaCallback(
+                    array($abstractFactory, 'createServiceWithName'),
+                    $canonicalName,
+                    $requestedName
+                );
+                unset($this->pendingAbstractFactoryRequests[$pendingKey]);
+                return $instance;
             } catch (\Exception $e) {
-                unset($this->pendingAbstractFactoryRequests[get_class($abstractFactory)]);
+                unset($this->pendingAbstractFactoryRequests[$pendingKey]);
+                $this->checkNestedContextStop(true);
                 throw new Exception\ServiceNotCreatedException(
                     sprintf(
                         'An abstract factory could not create an instance of %s%s.',
@@ -1082,10 +1077,42 @@ class ServiceManager implements ServiceLocatorInterface
                     $e
                 );
             }
-            if ($instance !== null) {
-                return $instance;
-            }
         }
+        return null;
+    }
+
+    /**
+     *
+     * @param string $cName
+     * @return self
+     */
+    protected function checkNestedContextStart($cName)
+    {
+        if ($this->nestedContextCounter === -1 || !isset($this->nestedContext[$cName])) {
+            $this->nestedContext[$cName] = null;
+        }
+        $this->nestedContextCounter++;
+        return $this;
+    }
+
+    /**
+     *
+     * @param bool $force
+     * @return self
+     */
+    protected function checkNestedContextStop($force = false)
+    {
+        if ($force) {
+            $this->nestedContextCounter = -1;
+            $this->nestedContext = array();
+            return $this;
+        }
+
+        $this->nestedContextCounter--;
+        if ($this->nestedContextCounter === -1) {
+            $this->nestedContext = array();
+        }
+        return $this;
     }
 
     /**
@@ -1149,7 +1176,7 @@ class ServiceManager implements ServiceLocatorInterface
         if (is_subclass_of($className, $type)) {
             return true;
         }
-        if (version_compare(PHP_VERSION, '5.3.7', '>=')) {
+        if (PHP_VERSION_ID >= 50307) {
             return false;
         }
         if (!interface_exists($type)) {
