@@ -65,6 +65,15 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     protected function tearDown()
     {
         Console::overrideIsConsole($this->usedConsoleBackup);
+
+        if (true !== $this->traceError) {
+            return;
+        }
+
+        $exception = $this->getApplication()->getMvcEvent()->getParam('exception');
+        if ($exception instanceof \Exception) {
+            throw $exception;
+        }
     }
 
     /**
@@ -78,12 +87,13 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
 
     /**
      * Set the trace error flag
-     * @param  bool $traceError
+     * @param  bool                       $traceError
      * @return AbstractControllerTestCase
      */
     public function setTraceError($traceError)
     {
         $this->traceError = $traceError;
+
         return $this;
     }
 
@@ -98,12 +108,13 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
 
     /**
      * Set the usage of the console router or not
-     * @param  bool $boolean
+     * @param  bool                       $boolean
      * @return AbstractControllerTestCase
      */
     public function setUseConsoleRequest($boolean)
     {
         $this->useConsoleRequest = (bool) $boolean;
+
         return $this;
     }
 
@@ -118,7 +129,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
 
     /**
      * Set the application config
-     * @param  array $applicationConfig
+     * @param  array                      $applicationConfig
      * @return AbstractControllerTestCase
      * @throws LogicException
      */
@@ -135,6 +146,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
             $applicationConfig['module_listener_options']['config_cache_enabled'] = false;
         }
         $this->applicationConfig = $applicationConfig;
+
         return $this;
     }
 
@@ -187,9 +199,9 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Set the request URL
      *
-     * @param  string $url
-     * @param  string|null $method
-     * @param  array|null $params
+     * @param  string                     $url
+     * @param  string|null                $method
+     * @param  array|null                 $params
      * @return AbstractControllerTestCase
      */
     public function url($url, $method = HttpRequest::METHOD_GET, $params = array())
@@ -199,6 +211,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
             preg_match_all('/(--\S+[= ]"\S*\s*\S*")|(--\S+=\S+|--\S+\s\S+|\S+)/', $url, $matches);
             $params = str_replace(array(' "', '"'), array('=', ''), $matches[0]);
             $request->params()->exchangeArray($params);
+
             return $this;
         }
 
@@ -219,8 +232,11 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
             $query = array_merge($query, $params);
         } elseif ($method == HttpRequest::METHOD_PUT) {
             if (count($params) != 0) {
-                array_walk($params,
-                    function (&$item, $key) { $item = $key . '=' . $item; }
+                array_walk(
+                    $params,
+                    function (&$item, $key) {
+                        $item = $key . '=' . $item;
+                    }
                 );
                 $content = implode('&', $params);
                 $request->setContent($content);
@@ -247,9 +263,9 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
      *
      * The URL provided set the request URI in the request object.
      *
-     * @param  string $url
+     * @param  string      $url
      * @param  string|null $method
-     * @param  array|null $params
+     * @param  array|null  $params
      * @throws \Exception
      */
     public function dispatch($url, $method = null, $params = array(), $isXmlHttpRequest = false)
@@ -270,15 +286,6 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
 
         $this->url($url, $method, $params);
         $this->getApplication()->run();
-
-        if (true !== $this->traceError) {
-            return;
-        }
-
-        $exception = $this->getApplication()->getMvcEvent()->getParam('exception');
-        if ($exception instanceof \Exception) {
-            throw $exception;
-        }
     }
 
     /**
@@ -309,7 +316,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Trigger an application event
      *
-     * @param  string $eventName
+     * @param  string                                $eventName
      * @return \Zend\EventManager\ResponseCollection
      */
     public function triggerApplicationEvent($eventName)
@@ -357,7 +364,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert modules were not loaded with the module manager
      *
-     * @param  array $modules
+     * @param array $modules
      */
     public function assertNotModulesLoaded(array $modules)
     {
@@ -388,13 +395,14 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
         if (null === $match) {
             $match = 0;
         }
+
         return $match;
     }
 
     /**
      * Assert response status code
      *
-     * @param  int $code
+     * @param int $code
      */
     public function assertResponseStatusCode($code)
     {
@@ -418,7 +426,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert not response status code
      *
-     * @param  int $code
+     * @param int $code
      */
     public function assertNotResponseStatusCode($code)
     {
@@ -472,13 +480,14 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
         $controllerIdentifier = $routeMatch->getParam('controller');
         $controllerManager    = $this->getApplicationServiceLocator()->get('ControllerManager');
         $controllerClass      = $controllerManager->get($controllerIdentifier);
+
         return get_class($controllerClass);
     }
 
     /**
      * Assert that the application route match used the given module
      *
-     * @param  string $module
+     * @param string $module
      */
     public function assertModuleName($module)
     {
@@ -498,7 +507,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used NOT the given module
      *
-     * @param  string $module
+     * @param string $module
      */
     public function assertNotModuleName($module)
     {
@@ -518,7 +527,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used the given controller class
      *
-     * @param  string $controller
+     * @param string $controller
      */
     public function assertControllerClass($controller)
     {
@@ -538,7 +547,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used NOT the given controller class
      *
-     * @param  string $controller
+     * @param string $controller
      */
     public function assertNotControllerClass($controller)
     {
@@ -558,7 +567,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used the given controller name
      *
-     * @param  string $controller
+     * @param string $controller
      */
     public function assertControllerName($controller)
     {
@@ -578,7 +587,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used NOT the given controller name
      *
-     * @param  string $controller
+     * @param string $controller
      */
     public function assertNotControllerName($controller)
     {
@@ -598,7 +607,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used the given action
      *
-     * @param  string $action
+     * @param string $action
      */
     public function assertActionName($action)
     {
@@ -618,7 +627,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used NOT the given action
      *
-     * @param  string $action
+     * @param string $action
      */
     public function assertNotActionName($action)
     {
@@ -638,7 +647,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used the given route name
      *
-     * @param  string $route
+     * @param string $route
      */
     public function assertMatchedRouteName($route)
     {
@@ -658,7 +667,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Assert that the application route match used NOT the given route name
      *
-     * @param  string $route
+     * @param string $route
      */
     public function assertNotMatchedRouteName($route)
     {
@@ -678,7 +687,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
      * Assert template name
      * Assert that a template was used somewhere in the view model tree
      *
-     * @param  string $templateName
+     * @param string $templateName
      */
     public function assertTemplateName($templateName)
     {
@@ -690,7 +699,7 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
      * Assert not template name
      * Assert that a template was not used somewhere in the view model tree
      *
-     * @param  string $templateName
+     * @param string $templateName
      */
     public function assertNotTemplateName($templateName)
     {
@@ -701,18 +710,19 @@ abstract class AbstractControllerTestCase extends PHPUnit_Framework_TestCase
     /**
      * Recursively search a view model and it's children for the given templateName
      *
-     * @param ViewModel $viewModel
-     * @param string $templateName
+     * @param  \Zend\View\Model\ModelInterface $viewModel
+     * @param  string    $templateName
      * @return boolean
      */
     protected function searchTemplates($viewModel, $templateName)
     {
-        if ($viewModel->getTemplate($templateName) == $templateName){
+        if ($viewModel->getTemplate($templateName) == $templateName) {
             return true;
         }
-        foreach ($viewModel->getChildren() as $child){
+        foreach ($viewModel->getChildren() as $child) {
             return $this->searchTemplates($child, $templateName);
         }
+
         return false;
     }
 }
