@@ -3,21 +3,21 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright  Copyright (c) 2005-2013 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
 /**
- * CS-Revision: 28.Mar.2013
+ * CS-Revision: 4.Nov.2013
  */
 return array(
-    // Zend_Captcha_AbstractWord
-    "Empty captcha value" => "Hodnota captcha nebyla zadána",
-    "Captcha ID field is missing" => "Chybí pole captcha ID",
-    "Captcha value is wrong" => "Chybná hodnota captcha",
-
-    // Zend_Captcha_ReCaptcha
-    "Missing captcha fields" => "Chybí captcha pole",
+    // Zend\Captcha\ReCaptcha
+    "Missing captcha fields" => "Chybí pole captcha",
     "Failed to validate captcha" => "Captchu se nepodařilo ověřit",
     "Captcha value is wrong: %value%" => "Hodnota captchy není správná: %value%",
+
+    // Zend\Captcha\Word
+    "Empty captcha value" => "Hodnota captcha nebyla zadána",
+    "Captcha ID field is missing" => "Chybí pole captcha ID",
+    "Captcha value is wrong" => "Hodnota captchy není správná",
 );
