@@ -53,6 +53,11 @@ return array(
     "The input is not between '%min%' and '%max%', inclusively" => "The input is not between '%min%' and '%max%', inclusively",
     "The input is not strictly between '%min%' and '%max%'" => "The input is not strictly between '%min%' and '%max%'",
 
+    // Zend\Validator\Bitwise
+    "The input has no common bit set with '%control%'" => "The input has no common bit set with '%control%'",
+    "The input doesn't have the same bits set as '%control%'" => "The input doesn't have the same bits set as '%control%'",
+    "The input has common bit set with '%control%'" => "The input has common bit set with '%control%'",
+
     // Zend\Validator\Callback
     "The input is not valid" => "The input is not valid",
     "An exception has been raised within the callback" => "An exception has been raised within the callback",
@@ -75,6 +80,9 @@ return array(
     "The input does not fit the date format '%format%'" => "The input does not fit the date format '%format%'",
 
     // Zend\Validator\DateStep
+    "Invalid type given. String, integer, array or DateTime expected" => "Invalid type given. String, integer, array or DateTime expected",
+    "The input does not appear to be a valid date" => "The input does not appear to be a valid date",
+    "The input does not fit the date format '%format%'" => "The input does not fit the date format '%format%'",
     "The input is not a valid step" => "The input is not a valid step",
 
     // Zend\Validator\Db\AbstractDb
